{
	"name" : "Belgium - Plan Comptable Minimum Normalise",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Localisation/Account charts",
	"depends" : ["base", "account"],
	"init_xml" : [],
	"demo_xml" : ["account_demo.xml"],
	"update_xml" : ["account_pcmn_belgium.xml"],
	"active": False,
	"installable": True
}
